==> soccerwindow2-2.0.0.tar.gz: soccerwindow2-2.0.0/src/qt3/debug_message_window.h <==
// -*-c++-*-

/*!
  \file debug_message_window.h
  \brief debug message viewer class Header File.
*/

/*
 *Copyright:

 Copyright (C) Hidehisa AKIYAMA

 This code is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This code is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this code; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef SOCCERWINDOW2_QT3_DEBUG_MESSAGE_FRAME_H
#define SOCCERWINDOW2_QT3_DEBUG_MESSAGE_FRAME_H

#include <qmainwindow.h>

#include <rcsc/types.h>

#include <boost/shared_ptr.hpp>

class QAction;
class QLineEdit;
class QRadioButton;
class QTabWidget;
class QTextEdit;
class QToolBar;

class MainData;
class DebugLogHolder;

//! debug manager frame class
class DebugMessageWindow
    : public QMainWindow {

    Q_OBJECT

private:

    MainData & M_main_data;

    //! debug log data holder
    boost::shared_ptr< DebugLogHolder > M_debug_holder;

    QToolBar * M_tool_bar;
    QLineEdit * M_find_box;
    QRadioButton * M_find_forward_rb;
    QRadioButton * M_find_backward_rb;

    QTabWidget * M_tab_widget;
    QTextEdit * M_message[11];

    QAction * M_show_debug_view_all_act;
    QAction * M_show_debug_view_self_act;
    QAction * M_show_debug_view_ball_act;
    QAction * M_show_debug_view_players_act;
    QAction * M_show_debug_view_comment_act;
    QAction * M_show_debug_view_figure_act;
    QAction * M_show_debug_view_target_act;
    QAction * M_show_debug_view_message_act;

    QAction * M_open_debug_log_dir_act;

    QAction * M_sync_act;
    QAction * M_decrement_act;
    QAction * M_increment_act;

    QAction * M_debug_level_act[16];

    //! log level flag
    int M_level;

    //! not used
    DebugMessageWindow();
    //! noncopyable
    DebugMessageWindow( const DebugMessageWindow & );
    //! noncopyable
    DebugMessageWindow & operator=( const DebugMessageWindow & );

public:

    DebugMessageWindow( QWidget * parent,
                        MainData & main_data );

    ~DebugMessageWindow();

private:

    void loadSettings();
    void saveSettings();

    void createActions();
    void createWindows();
    void createToolBar();

    void loadDebugLogDir( const rcsc::SideID side,
                          const std::string & dir_path );

private slots:

    void changeCurrentTab( QWidget * widget );

    void toggleShowDebugViewAll( bool checked );
    void toggleShowDebugViewSelf( bool checked );
    void toggleShowDebugViewBall( bool checked );
    void toggleShowDebugViewPlayers( bool checked );
    void toggleShowDebugViewComment( bool checked );
    void toggleShowDebugViewFigure( bool checked );
    void toggleShowDebugViewTarget( bool checked );
    void toggleShowDebugViewMessage( bool checked );

    void showDebugLogDirDialog();

    void syncCycle();
    void decrementCycle();
    void incrementCycle();

    void findExistString();
    void findString( const QString & expr );

    void toggleDebugLevel_1( bool checked );
    void toggleDebugLevel_2( bool checked );
    void toggleDebugLevel_3( bool checked );
    void toggleDebugLevel_4( bool checked );
    void toggleDebugLevel_5( bool checked );
    void toggleDebugLevel_6( bool checked );
    void toggleDebugLevel_7( bool checked );
    void toggleDebugLevel_8( bool checked );
    void toggleDebugLevel_9( bool checked );
    void toggleDebugLevel_10( bool checked );
    void toggleDebugLevel_11( bool checked );
    void toggleDebugLevel_12( bool checked );
    void toggleDebugLevel_13( bool checked );
    void toggleDebugLevel_14( bool checked );
    void toggleDebugLevel_15( bool checked );
    void toggleDebugLevel_16( bool checked );

public slots:

    void clearAll();
    void updateMessage();

signals:

    void configured();

};

#endif

==> soccerwindow2-2.1.1.tar.gz: soccerwindow2-2.1.1/src/qt3/debug_message_window.h <==
// -*-c++-*-

/*!
  \file debug_message_window.h
  \brief debug message viewer class Header File.
*/

/*
 *Copyright:

 Copyright (C) Hidehisa AKIYAMA

 This code is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2, or (at your option)
 any later version.

 This code is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this code; see the file COPYING.  If not, write to
 the Free Software Foundation, 675 Mass Ave, Cambridge, MA 02139, USA.

 *EndCopyright:
 */

/////////////////////////////////////////////////////////////////////

#ifndef SOCCERWINDOW2_QT3_DEBUG_MESSAGE_FRAME_H
#define SOCCERWINDOW2_QT3_DEBUG_MESSAGE_FRAME_H

#include <qmainwindow.h>

#include <rcsc/types.h>

#include <boost/shared_ptr.hpp>

class QAction;
class QActionGroup;
class QLineEdit;
class QRadioButton;
class QTabWidget;
class QTextEdit;
class QToolBar;

class MainData;
class DebugLogHolder;

//! debug manager frame class
class DebugMessageWindow
    : public QMainWindow {

    Q_OBJECT

private:

    MainData & M_main_data;

    //! debug log data holder
    boost::shared_ptr< DebugLogHolder > M_debug_holder;

    QToolBar * M_tool_bar;
    QLineEdit * M_find_box;
    QRadioButton * M_find_forward_rb;
    QRadioButton * M_find_backward_rb;

    QTabWidget * M_tab_widget;
    QTextEdit * M_message[11];

    QAction * M_show_debug_view_all_act;
    QAction * M_show_debug_view_self_act;
    QAction * M_show_debug_view_ball_act;
    QAction * M_show_debug_view_players_act;
    QAction * M_show_debug_view_comment_act;
    QAction * M_show_debug_view_figure_act;
    QAction * M_show_debug_view_target_act;
    QAction * M_show_debug_view_message_act;

    QAction * M_show_debug_log_view_act;

    QAction * M_open_debug_log_dir_act;

    QAction * M_sync_act;
    QAction * M_decrement_act;
    QAction * M_increment_act;

    QString M_debug_text[16];
    QActionGroup * M_debug_level_act_group;
    QAction * M_debug_level_act[16];

    //! not used
    DebugMessageWindow();
    //! noncopyable
    DebugMessageWindow( const DebugMessageWindow & );
    //! noncopyable
    DebugMessageWindow & operator=( const DebugMessageWindow & );

public:

    DebugMessageWindow( QWidget * parent,
                        MainData & main_data );

    ~DebugMessageWindow();

private:

    void loadSettings();
    void saveSettings();

    void createActions();
    void createWindows();
    void createToolBar();

    void loadDebugLogDir( const rcsc::SideID side,
                          const std::string & dir_path );

private slots:

    void changeCurrentTab( QWidget * widget );

    void toggleShowDebugViewAll( bool checked );
    void toggleShowDebugViewSelf( bool checked );
    void toggleShowDebugViewBall( bool checked );
    void toggleShowDebugViewPlayers( bool checked );
    void toggleShowDebugViewComment( bool checked );
    void toggleShowDebugViewFigure( bool checked );
    void toggleShowDebugViewTarget( bool checked );
    void toggleShowDebugViewMessage( bool checked );

    void toggleShowDebugLogView( bool checked );

    void showDebugLogDirDialog();

    void syncCycle();
    void decrementCycle();
    void incrementCycle();

    void findExistString();
    void findString( const QString & expr );

    void toggleDebugLevel( int level );

public slots:

    void clearAll();
    void updateMessage();

signals:

    void configured();

};

#endif
